"""
Periodic Table Info - Print all the elements in the Periodic Table of the Elements. 
Copyright (C) 2017-2022 Dog Face Development Co.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 3 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
# This is the main program file for Periodic Table Info.

# Imports all other files.
from elements import element_print_out

# Print all elements and input field
print(element_print_out())

input_from_user = input ("Please enter the element you would like to learn more about: ")


# Prints the information the user want based on what input they have selected.
if input_from_user.lower() == "" :
    print("")

else :
    print("Sorry, that is not an element of the current Periodic Table!")
    print("Remember to type it like this: 'Sodium' or 'sodium'. Capitalization doesn't matter. No punctuation, please!")



"""
Periodic Table Info - Print all the elements in the Periodic Table of the Elements. 
Copyright (C) 2017-2022 Dog Face Development Co.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 3 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

# This prints all of the elements to the screen. And then presents the enter field.
#This is also the joining file.

# Prints the elements to the screen
def element_print_out():
    print("--THE PERIODIC TABLE ELEMENTS--")
    print("\n")
    print("1. Hydrogen (H)")
    print("")
    print("Alkali Metals - Group 1")
    print("3. Lithium (Li)")
    print("11. Sodium (Na)")
    print("19. Potassium (K)")
    print("37. Rubidium (Rb)")
    print("55. Cesium (Cs)")
    print("87. Francium (Fr)")
    print("")
    print("Alkaline Earth Metals - Group 2")
    print("4. Beryllium (Be)")
    print("12. Magnesium (Mg)")
    print("20. Calcium (Ca)")
    print("38. Strontium (Sr)")
    print("56. Barium (Ba)")
    print("88. Radium (Ra)")
    print("")
    print("Transition Elements - Groups 3-12")
    print("21. Scandium (Sc)")
    print("22. Titanium (Ti)")
    print("23. Vanadium (V)")
    print("24. Chromium (Cr)")
    print("25. Manganese (Mn)")
    print("26. Iron (Fe)")
    print("27. Cobalt (Co)")
    print("28. Nickel (Ni)")
    print("29. Copper (Cu)")
    print("30. Zinc (Zn)")
    print("39. Yttrium (Y)")
    print("40. Zirconium")
    print("41. Niobium (Nb)")
    print("42. Molybdenum (Mo)")
    print("43. Technetium (Tc)")
    print("44. Ruthenium (Ru)")
    print("45. Rhodium (Rh)")
    print("46. Palladium (Pd)")
    print("47. Silver (Ag)")
    print("48. Cadmium (Cd)")
    print("72. Hafnium (Hf)")
    print("73. Tantalum (Ta)")
    print("74. Tungsten (W)")
    print("75. Rhenium (Re)")
    print("76. Osium (Os)")
    print("77. Iridium (Ir)")
    print("78. Platinum (Pt)")
    print("79. Gold (Au)")
    print("80. Mercury (Hg)")
    print("")
    print("Boron Elements - Group 13")
    print("5. Boron (B)")
    print("13. Aluminum (Al)")
    print("31. Gallium (Ga)")
    print("49. Indium (In)")
    print("81. Thallium (Ti)")
    print("113. Ellement 113 - Unkown Element (Uut)")
    print("")
    print("Carbon Elements - Group 14")
    print("6. Carbon (C)")
    print("14. Silicon (Si)")
    print("32. Germanium (Ge)")
    print("50. Tin (Sn)")
    print("82. Lead (Pb)")
    print("114. Flerovium (Fi)")
    print("")
    print("Nitrogen Elements - Group 15")
    print("7. Nitrogen (N)")
    print("15. Phosphorus (P)")
    print("33. Arsenic (As)")
    print("51. Antimony (Sb)")
    print("83. Bismuth (Bi)")
    print("115. Element 115 - Unkown Element (Uup)")
    print("")
    print("Oxygen Elements - Group 16")
    print("8. Oxygen (O)")
    print("16. Sulfur (S)")
    print("34. Selenium (Se)")
    print("52. Tellurium (Te)")
    print("84. Polonium (Po)")
    print("116. Livermorium (Lv)")
    print("")
    print("Halogen Elements - Group 17")
    print("9. Flurine (F)")
    print("17. Chlorine (Cl)")
    print("35. Bromine (Br)")
    print("53. Iodone (I)")
    print("85. Astatine (At)")
    print("117. Element 117 - Unkown Element (Uus)")
    print("")
    print("Noble Gases - Group 18")
    print("2. Helium (He)")
    print("10. Neon (Ne)")
    print("18. Argon (Ar)")
    print("36. Krypton (Kr)")
    print("54. Xenon (Xe)")
    print("86. Radon (Rn)")
    print("118. Element 118 - Unkown Element (Uuo)")
    print("")
    print("Lanthanoid Elements")
    



from setuptools import setup

def readme():
    with open('README.md') as f:
        return f.read()

setup(
	name='periodic-table-info',
	version='0.3.0',
    description='Print all the elements in the Periodic Table of the Elements, with an interactive prompt to learn more.',
    long_description=readme(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Education',
    ],
    keywords='periodic table education info cli',
    url='https://github.com/Dog-Face-Development/Periodic-Table-Info',
    author='willtheorangeguy',
    py_modules = ['elements', 'print', 'main'],
    entry_points={
        'console_scripts': [
            'periodic-table-info=elements:element_print_out'
        ]
    },
)
